==============
Optics Module
==============

.. topic:: Abstract

    Contains docstrings of Physics-Optics module


.. toctree::
   :titlesonly:

   gaussopt.rst
   medium.rst
   polarization.rst
   utils.rst
   waves.rst
